# 💬 Streamlit Disqus

[![GitHub][github_badge]][github_link] [![PyPI][pypi_badge]][pypi_link]

## Installation

```sh
pip install streamlit-disqus-darkmode
```

## Getting started

```python
from streamlit_disqus_darkmode import st_disqus

st_disqus("streamlit-disqus-demo")
```

## Demo

[![Open in Streamlit][share_badge]][share_link]

[![Preview][share_img]][share_link]

[share_badge]: https://static.streamlit.io/badges/streamlit_badge_black_white.svg
[share_link]: https://share.streamlit.io/okld/streamlit-gallery/main?p=disqus
[share_img]: https://raw.githubusercontent.com/okld/streamlit-disqus/main/preview.png
[github_badge]: https://badgen.net/badge/icon/GitHub?icon=github&color=black&label
[github_link]: https://github.com/okld/streamlit-disqus
[pypi_badge]: https://badgen.net/pypi/v/streamlit-disqus?icon=pypi&color=black&label
[pypi_link]: https://pypi.org/project/streamlit-disqus
